#!/usr/bin/env python

"""
This is a simple text substitution script which reads data from stdin and
writes the data back to stdout.  A list of replacements is specified on
the command line in the form of search=replace.  Patterns in the input
file in the form of @key@ will be replaced by the replacement.  Patterns
of @@ will be replaced by a single @.
"""

import sys
import re

version = '20141109'

# Parse the command line
replacements = {}

for i in sys.argv[1:]:
    parts = i.split('=', 1)
    if len(parts) == 2:
        replacements[parts[0]] = parts[1]

# Replacement function
def fn(mo):
    key = mo.group(1);

    if len(key) == 0:
        return '@'

    if key in replacements:
        return replacements[key]

    raise ValueError('key not present in subsitution data: ' + key)

# Build regex and process input
regex = re.compile('@(.*?)@')
for line in sys.stdin:
    sys.stdout.write(regex.sub(fn, line))

